
.. image:: https://badge.fury.io/py/pyDHTMLParser.png
    :target: https://pypi.python.org/pypi/pyDHTMLParser

.. image:: https://img.shields.io/pypi/dm/pyDHTMLParser.svg
    :target: https://pypi.python.org/pypi/pyDHTMLParser

.. image:: https://readthedocs.org/projects/pyDHTMLParser/badge/?version=latest
    :target: http://pyDHTMLParser.readthedocs.org/

.. image:: https://img.shields.io/github/issues/Bystroushaak/pyDHTMLParser.svg
    :target: https://github.com/Bystroushaak/pyDHTMLParser/issues

.. image:: https://img.shields.io/pypi/l/pyDHTMLParser.svg

What is it?
===========
DHTMLParser is a lightweight HTML/XML parser created for one purpose - quick and easy 
picking selected tags from DOM.

It can be very useful when you are in need to write own "guerilla" API for some webpage, or a scrapper.

If you want, you can also create HTML/XML documents more easily than by joining strings.

Documentation
=============

Full module documentation can be found here: http://pyDHTMLParser.rtfd.org